@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Any
 from libtmux import Server, Session, Window, Pane
 from dotenv import dotenv_values
 import os
@@ -12,7 +12,7 @@ from parasut_cli.config.settings import APP_DIR, env
 
 
 class Receiver:
-    def __init__(self):
+    def __init__(self) -> None:
         # env variables
         try:
             # core
@@ -63,11 +63,11 @@ class Receiver:
         self._tmux_server: Server
         self._tmux_session_parasut_ws_setup: Session
         self._tmux_session_parasut_ws_editor: Session
-        self._dep_versions = dict(
+        self._dep_versions: Dict[str, Dict[str, Any]] = dict(
             ui_library=dict(linked=False, value=""),
             shared_logic=dict(linked=False, value=""),
         )
-        self._linking_options = dict(
+        self._linking_options: Dict[str, str] = dict(
             ui_library="ui-library",
             shared_logic="shared-logic",
         )
@@ -77,43 +77,43 @@ class Receiver:
             launch_sidekiq="bundle exec sidekiq",
             launch_rails="rails server",
         )
-        self._billing_commands = dict(
+        self._billing_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_ruby_version=f"rvm use {self.BILLING_RUBY_V}",
             launch_sidekiq="bundle exec sidekiq",
             launch_rails=f"rails server -p {self.BILLING_RAILS_PORT}",
         )
-        self._e_doc_broker_commands = dict(
+        self._e_doc_broker_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_ruby_version=f"rvm use {self.E_DOC_BROKER_RUBY_V}",
             launch_sidekiq="bundle exec sidekiq",
             launch_rails=f"rails server -p {self.E_DOC_BROKER_RAILS_PORT}",
         )
-        self._phoenix_commands = dict(
+        self._phoenix_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_yarn_version=f"yvm use {self.PHOENIX_YARN_V}",
             choose_node_version=f"nvm use {self.PHOENIX_NODE_V}",
             ember_serve="PROJECT_TARGET=phoenix ember s",
         )
-        self._client_commands = dict(
+        self._client_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_yarn_version=f"yvm use {self.CLIENT_YARN_V}",
             choose_node_version=f"nvm use {self.CLIENT_NODE_V}",
             ember_serve=f"./node_modules/ember-cli/bin/ember s --live-reload-port {self.CLIENT_EMBER_PORT}",
         )
-        self._trinity_commands = dict(
+        self._trinity_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_yarn_version=f"yvm use {self.TRINITY_YARN_V}",
             choose_node_version=f"nvm use {self.TRINITY_NODE_V}",
             ember_serve="ember s --live-reload-port 6505",
         )
-        self._ui_library_commands = dict(
+        self._ui_library_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_yarn_version=f"yvm use {self.UI_LIBRARY_YARN_V}",
             choose_node_version=f"nvm use {self.UI_LIBRARY_NODE_V}",
             ember_serve=f"PROJECT_TARGET=phoenix ember s --live-reload-port {self.UI_LIBRARY_EMBER_PORT}",
         )
-        self._shared_logic_commands = dict(
+        self._shared_logic_commands: Dict[str, str] = dict(
             launch_text_editor=self.PARASUT_CLI_TEXT_EDITOR,
             choose_yarn_version=f"yvm use {self.SHARED_LOGIC_YARN_V}",
             choose_node_version=f"nvm use {self.SHARED_LOGIC_NODE_V}",
@@ -218,7 +218,7 @@ class Receiver:
         self._tmux_session_parasut_ws_editor.select_window(1)
 
     def switch_server_rails_frontend(self, target_repo: str) -> None:
-        server_repo = f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}"
+        server_repo: str = f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}"
 
         self._change_directory(server_repo)
 
@@ -241,8 +241,8 @@ class Receiver:
                 ]
             )
 
-    def switch_server_rails_addling(self, target_addling: str):
-        server_repo = f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}"
+    def switch_server_rails_addling(self, target_addling: str) -> None:
+        server_repo: str = f"{self.PARASUT_BASE_DIR}/{self.SERVER_DIR}"
 
         self._change_directory(server_repo)
 
@@ -265,9 +265,12 @@ class Receiver:
                 ]
             )
 
-
     def do_linking(self, base_repo: str, target_repos: List[str]) -> None:
         base_path: str = self._find_repo_path(base_repo)
+        dep_key: str = ""
+        dep_value: str = ""
+        target_path: str = ""
+        json_file: str = ""
 
         self._initialize_dep_versions(base_repo)
         self._change_directory(base_path)
@@ -322,6 +325,10 @@ class Receiver:
 
     def undo_linking(self, base_repo: str, repos: List[str]) -> None:
         base_path: str = self._find_repo_path(base_repo)
+        dep_key: str = ""
+        dep_value: str = ""
+        target_path: str = ""
+        json_file: str = ""
 
         self._initialize_dep_versions(base_repo)
         self._change_directory(base_path)
@@ -428,13 +435,13 @@ class Receiver:
             )
 
     def _store_linking_info(self, dep_versions: Dict) -> None:
-        pickle_file_path = f"{APP_DIR}/state/link_info.pickle"
+        pickle_file_path: str = f"{APP_DIR}/state/link_info.pickle"
 
         with open(pickle_file_path, "wb") as handle:
             pickle.dump(dep_versions, handle, protocol=pickle.HIGHEST_PROTOCOL)
 
     def _initialize_dep_versions(self, base_repo: str) -> None:
-        pickle_file_path = f"{APP_DIR}/state/link_info.pickle"
+        pickle_file_path: str = f"{APP_DIR}/state/link_info.pickle"
 
         try:
             with open(pickle_file_path, "rb") as handle:
@@ -451,10 +458,10 @@ class Receiver:
             else:
                 self._dep_versions[i]["linked"] = False
 
-    def _is_linked(self, base_repo: str, dep_key: str):
+    def _is_linked(self, base_repo: str, dep_key: str) -> bool:
         base_path: str = self._find_repo_path(base_repo)
-        checking_word = "link"
-        json_file = "package.json"
+        checking_word: str = "link"
+        json_file: str = "package.json"
 
         self._change_directory(base_path)
 
